@@ -120,7 +120,7 @@ use File::Glob qw(:case);
 %Modules = (
 
     'Archive::Tar' => {
-        'DISTRIBUTION' => 'BINGOS/Archive-Tar-2.14.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Archive-Tar-2.24.tar.gz',
         'FILES'        => q[cpan/Archive-Tar],
         'BUGS'         => 'bug-archive-tar@rt.cpan.org',
         'EXCLUDED'     => [
@@ -173,7 +173,7 @@ use File::Glob qw(:case);
     },
 
     'B::Debug' => {
-        'DISTRIBUTION' => 'RURBAN/B-Debug-1.23.tar.gz',
+        'DISTRIBUTION' => 'RURBAN/B-Debug-1.24.tar.gz',
         'FILES'        => q[cpan/B-Debug],
         'EXCLUDED'     => ['t/pod.t'],
     },
@@ -188,10 +188,9 @@ use File::Glob qw(:case);
     },
 
     'bignum' => {
-        'DISTRIBUTION' => 'PJACKLAM/bignum-0.43.tar.gz',
+        'DISTRIBUTION' => 'PJACKLAM/bignum-0.47.tar.gz',
         'FILES'        => q[cpan/bignum],
         'EXCLUDED'     => [
-            qr{^inc/Module/},
             qr{^t/author-},
             qw( t/00sig.t
                 t/01load.t
@@ -199,13 +198,6 @@ use File::Glob qw(:case);
                 t/03podcov.t
                 ),
         ],
-        'CUSTOMIZED'   => [
-            qw(
-               lib/Math/BigFloat/Trace.pm
-               lib/Math/BigInt/Trace.pm lib/bigint.pm
-               lib/bignum.pm lib/bigrat.pm
-            )
-        ],
     },
 
     'Carp' => {
@@ -404,9 +396,9 @@ use File::Glob qw(:case);
     },
 
     'Encode' => {
-        'DISTRIBUTION' => 'DANKOGAI/Encode-2.86.tar.gz',
+        'DISTRIBUTION' => 'DANKOGAI/Encode-2.88.tar.gz',
         'FILES'        => q[cpan/Encode],
-        'CUSTOMIZED'   => [ qw[ Encode.xs ] ],
+        'CUSTOMIZED'   => [ qw(Unicode/Unicode.pm) ],
     },
 
     'encoding::warnings' => {
@@ -700,8 +692,10 @@ use File::Glob qw(:case);
         'DISTRIBUTION' => 'MAKAMAKA/JSON-PP-2.27400.tar.gz',
         'FILES'        => q[cpan/JSON-PP],
         'CUSTOMIZED'   => [
-            # CVE-2016-1238
-            qw( bin/json_pp lib/JSON/PP.pm ),
+            'bin/json_pp',    # CVE-2016-1238
+            'lib/JSON/PP.pm', # CVE-2016-1238, CPAN RT 118469
+            't/011_pc_expo.t',      # CPAN RT 118469
+            't/018_json_checker.t', # CPAN RT 118469
         ],
     },
 
@@ -731,7 +725,7 @@ use File::Glob qw(:case);
     },
 
     'Locale-Codes' => {
-        'DISTRIBUTION' => 'SBECK/Locale-Codes-3.40.tar.gz',
+        'DISTRIBUTION' => 'SBECK/Locale-Codes-3.42.tar.gz',
         'FILES'        => q[cpan/Locale-Codes],
         'EXCLUDED'     => [
             qw( README.first
@@ -767,10 +761,9 @@ use File::Glob qw(:case);
     },
 
     'Math::BigInt' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-1.999726.tar.gz',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-1.999806.tar.gz',
         'FILES'        => q[cpan/Math-BigInt],
         'EXCLUDED'     => [
-            qr{^inc/},
             qr{^examples/},
             qr{^t/author-},
             qw( t/00sig.t
@@ -782,10 +775,11 @@ use File::Glob qw(:case);
     },
 
     'Math::BigInt::FastCalc' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-FastCalc-0.42.tar.gz',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-FastCalc-0.5005.tar.gz',
         'FILES'        => q[cpan/Math-BigInt-FastCalc],
         'EXCLUDED'     => [
-            qr{^inc/},
+            qr{^t/author-},
+            qr{^t/Math/BigInt/Lib/TestUtil.pm},
             qw( t/00sig.t
                 t/01load.t
                 t/02pod.t
@@ -805,10 +799,9 @@ use File::Glob qw(:case);
     },
 
     'Math::BigRat' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigRat-0.260804.tar.gz',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigRat-0.2611.tar.gz',
         'FILES'        => q[cpan/Math-BigRat],
         'EXCLUDED'     => [
-            qr{^inc/},
             qr{^t/author-},
             qw( t/00sig.t
                 t/01load.t
@@ -821,6 +814,11 @@ use File::Glob qw(:case);
     'Math::Complex' => {
         'DISTRIBUTION' => 'ZEFRAM/Math-Complex-1.59.tar.gz',
         'FILES'        => q[cpan/Math-Complex],
+        'CUSTOMIZED'   => [
+            'lib/Math/Complex.pm', # CPAN RT 118467
+            't/Complex.t',         # CPAN RT 118467
+            't/Trig.t',            # CPAN RT 118467
+        ],
         'EXCLUDED'     => [
             qw( t/pod.t
                 t/pod-coverage.t
@@ -845,7 +843,7 @@ use File::Glob qw(:case);
     },
 
     'Module::CoreList' => {
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20160920.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20161120.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
     },
 
@@ -876,13 +874,17 @@ use File::Glob qw(:case);
     },
 
     'Net::Ping' => {
-        'DISTRIBUTION' => 'RURBAN/Net-Ping-2.51.tar.gz',
+        'DISTRIBUTION' => 'RURBAN/Net-Ping-2.55.tar.gz',
         'FILES'        => q[dist/Net-Ping],
         'EXCLUDED'     => [
+            qw(README.md.PL),
             qw(t/020_external.t),
             qw(t/600_pod.t),
             qw(t/601_pod-coverage.t),
         ],
+        'CUSTOMIZED'   => [
+            qw( t/000_load.t t/001_new.t t/010_pingecho.t t/500_ping_icmp.t),
+        ],
 
     },
 
@@ -977,7 +979,7 @@ use File::Glob qw(:case);
     },
 
     'Pod::Simple' => {
-        'DISTRIBUTION' => 'MARCGREEN/Pod-Simple-3.32.tar.gz',
+        'DISTRIBUTION' => 'MARCGREEN/Pod-Simple-3.35.tar.gz',
         'FILES'        => q[cpan/Pod-Simple],
     },
 
@@ -987,8 +989,11 @@ use File::Glob qw(:case);
     },
 
     'podlators' => {
-        'DISTRIBUTION' => 'RRA/podlators-4.08.tar.gz',
+        'DISTRIBUTION' => 'RRA/podlators-4.09.tar.gz',
         'FILES'        => q[cpan/podlators pod/perlpodstyle.pod],
+        'EXCLUDED'     => [
+            qr{^docs/metadata/},
+        ],
 
         'MAP' => {
             ''                 => 'cpan/podlators/',
@@ -1005,6 +1010,14 @@ use File::Glob qw(:case);
     'Scalar-List-Utils' => {
         'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.46.tar.gz',
         'FILES'        => q[cpan/Scalar-List-Utils],
+        'CUSTOMIZED'   => [
+            'lib/List/Util.pm',    # CPAN RT 118470
+            'lib/List/Util/XS.pm', # CPAN RT 118470
+            'lib/Scalar/Util.pm',  # CPAN RT 118470
+            'lib/Sub/Util.pm',     # CPAN RT 118470
+            't/lln.t',             # CPAN RT 118470
+            't/uniq.t',            # CPAN RT 118470
+        ],
     },
 
     'Search::Dict' => {
@@ -1054,9 +1067,10 @@ use File::Glob qw(:case);
     },
 
     'Term::ANSIColor' => {
-        'DISTRIBUTION' => 'RRA/Term-ANSIColor-4.05.tar.gz',
+        'DISTRIBUTION' => 'RRA/Term-ANSIColor-4.06.tar.gz',
         'FILES'        => q[cpan/Term-ANSIColor],
         'EXCLUDED'     => [
+            qr{^docs/},
             qr{^examples/},
             qr{^t/data/},
             qr{^t/docs/},
@@ -1152,7 +1166,7 @@ use File::Glob qw(:case);
     },
 
     'Test::Simple' => {
-        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302059.tar.gz',
+        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302073.tar.gz',
         'FILES'        => q[cpan/Test-Simple],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1265,12 +1279,12 @@ use File::Glob qw(:case);
     },
 
     'Time::HiRes' => {
-        'DISTRIBUTION' => 'JHI/Time-HiRes-1.9740.tar.gz',
+        'DISTRIBUTION' => 'JHI/Time-HiRes-1.9741.tar.gz',
         'FILES'        => q[dist/Time-HiRes],
     },
 
     'Time::Local' => {
-        'DISTRIBUTION' => 'DROLSKY/Time-Local-1.24.tar.gz',
+        'DISTRIBUTION' => 'DROLSKY/Time-Local-1.25.tar.gz',
         'FILES'        => q[cpan/Time-Local],
         'EXCLUDED'     => [
             qr{^xt/},
@@ -1289,7 +1303,7 @@ use File::Glob qw(:case);
     },
 
     'Unicode::Collate' => {
-        'DISTRIBUTION' => 'SADAHIRO/Unicode-Collate-1.14.tar.gz',
+        'DISTRIBUTION' => 'SADAHIRO/Unicode-Collate-1.19.tar.gz',
         'FILES'        => q[cpan/Unicode-Collate],
         'EXCLUDED'     => [
             qr{N$},
@@ -1304,7 +1318,7 @@ use File::Glob qw(:case);
 
     'Unicode::Normalize' => {
         'DISTRIBUTION' => 'KHW/Unicode-Normalize-1.25.tar.gz',
-        'FILES'        => q[cpan/Unicode-Normalize],
+        'FILES'        => q[dist/Unicode-Normalize],
         'EXCLUDED'     => [
             qw( MANIFEST.N
                 Normalize.pmN
